@@ -12,6 +12,8 @@ from apscheduler.schedulers.blocking import BlockingScheduler
 from sentry_sdk import capture_exception
 
 from robotoff import settings, slack
+from robotoff.elasticsearch import get_es_client
+from robotoff.elasticsearch.export import ElasticsearchExporter
 from robotoff.insights.annotate import (
     UPDATED_ANNOTATION_RESULT,
     InsightAnnotatorFactory,
@@ -200,6 +202,11 @@ def _update_data():
     except requests.exceptions.RequestException:
         logger.exception("Exception during product dataset refresh")
 
+    try:
+        ElasticsearchExporter(get_es_client()).load_all_indices()
+    except Exception as e:
+        logger.exception("Exception during ES indices creation", exc_info=e)
+
 
 def generate_insights():
     """Generate and import category insights from the latest dataset dump, for
